---
last_modified_on: "2020-07-13"
delivery_guarantee: "at_least_once"
component_title: "AWS S3"
description: "The Vector `aws_s3` sink batches `log` events to Amazon Web Service's S3 service via the `PutObject` API endpoint."
event_types: ["log"]
function_category: "transmit"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+aws_s3%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "aws_s3|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sinks/aws_s3.rs
status: "prod-ready"
title: "AWS S3 Sink"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import SVG from 'react-inlinesvg';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `aws_s3` sink
[batches](#buffers--batches) [`log`][docs.data-model.log] events to [Amazon Web
Service's S3 service][urls.aws_s3] via the [`PutObject` API
endpoint](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTObjectPUT.html).

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/aws_s3.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "aws_s3" # required
  inputs = ["my-source-or-transform-id"] # required
  bucket = "my-bucket" # required
  compression = "gzip" # optional, default
  healthcheck = true # optional, default
  region = "us-east-1" # required, required when endpoint = ""

  # Batch
  batch.max_bytes = 10000000 # optional, default, bytes
  batch.max_events = 1000 # optional, no default, events
  batch.timeout_secs = 300 # optional, default, seconds

  # Buffer
  buffer.max_events = 500 # optional, default, events, relevant when type = "memory"
  buffer.type = "memory" # optional, default

  # Encoding
  encoding.codec = "text" # optional, default

  # Naming
  key_prefix = "date=%F/" # optional, default
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "aws_s3" # required
  inputs = ["my-source-or-transform-id"] # required
  assume_role = "arn:aws:iam::123456789098:role/my_role" # optional, no default
  bucket = "my-bucket" # required
  compression = "gzip" # optional, default
  endpoint = "127.0.0.0:5000/path/to/service" # optional, no default, relevant when region = ""
  healthcheck = true # optional, default
  region = "us-east-1" # required, required when endpoint = ""

  # ACL
  acl = "private" # optional, no default
  grant_full_control = "79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be" # optional, no default
  grant_read = "79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be" # optional, no default
  grant_read_acp = "79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be" # optional, no default
  grant_write_acp = "79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be" # optional, no default

  # Batch
  batch.max_bytes = 10000000 # optional, default, bytes
  batch.max_events = 1000 # optional, no default, events
  batch.timeout_secs = 300 # optional, default, seconds

  # Buffer
  buffer.max_events = 500 # optional, default, events, relevant when type = "memory"
  buffer.max_size = 104900000 # required, bytes, required when type = "disk"
  buffer.type = "memory" # optional, default
  buffer.when_full = "block" # optional, default

  # Content Type
  content_encoding = "gzip" # optional, no default
  content_type = "text/x-log" # optional, default

  # Encoding
  encoding.codec = "text" # optional, default
  encoding.except_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.only_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.timestamp_format = "rfc3339" # optional, default

  # Encryption
  server_side_encryption = "AES256" # optional, no default
  ssekms_key_id = "abcd1234" # optional, no default, relevant when server_side_encryption = "aws:kms"

  # Metadata
  tags.Tag1 = "Value1" # example

  # Naming
  filename_append_uuid = true # optional, default
  filename_extension = "log" # optional, default
  filename_time_format = "%s" # optional, default
  key_prefix = "date=%F/" # optional, default

  # Request
  request.in_flight_limit = 50 # optional, default, requests
  request.rate_limit_duration_secs = 1 # optional, default, seconds
  request.rate_limit_num = 250 # optional, default
  request.retry_attempts = 18446744073709551615 # optional, default
  request.retry_initial_backoff_secs = 1 # optional, default, seconds
  request.retry_max_duration_secs = 10 # optional, default, seconds
  request.timeout_secs = 30 # optional, default, seconds

  # Storage
  storage_class = "STANDARD" # optional, no default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={{"private":"Owner gets FULL_CONTROL. No one else has access rights (default).","public-read":"Owner gets FULL_CONTROL. The AllUsers group gets READ access.","public-read-write":"Owner gets FULL_CONTROL. The AllUsers group gets READ and WRITE access. Granting this on a bucket is generally not recommended.","aws-exec-read":"Owner gets FULL_CONTROL. Amazon EC2 gets READ access to GET an Amazon Machine Image (AMI) bundle from Amazon S3.","authenticated-read":"Owner gets FULL_CONTROL. The AuthenticatedUsers group gets READ access.","log-delivery-write":"The LogDelivery group gets WRITE and READ_ACP permissions on the bucket. For more information about logs, see [Amazon S3 Server Access Logging](https://docs.aws.amazon.com/AmazonS3/latest/dev/ServerLogs.html)."}}
  examples={["private","public-read","public-read-write","aws-exec-read","authenticated-read","log-delivery-write"]}
  groups={[]}
  name={"acl"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### acl

Canned ACL to apply to the created objects. For more information, see [Canned
ACL][urls.aws_s3_canned_acl].
 See [Object access control list (ACL)](#object-access-control-list-acl) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["arn:aws:iam::123456789098:role/my_role"]}
  groups={[]}
  name={"assume_role"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### assume_role

The ARN of an [IAM role][urls.aws_iam_role] to assume at startup.
 See [AWS Authentication](#aws-authentication) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### batch

Configures the sink batching behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={10000000}
  enumValues={null}
  examples={[10000000]}
  groups={[]}
  name={"max_bytes"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_bytes

The maximum size of a batch, in bytes, before it is flushed.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[1000]}
  groups={[]}
  name={"max_events"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum size of a batch, in events, before it is flushed.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={true}
  defaultValue={300}
  enumValues={null}
  examples={[300]}
  groups={[]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum age of a batch before it is flushed.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["my-bucket"]}
  groups={[]}
  name={"bucket"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### bucket

The S3 bucket name. Do not include a leading `s3://` or a trailing `/`.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"buffer"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### buffer

Configures the sink specific buffer behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={500}
  enumValues={null}
  examples={[500]}
  groups={[]}
  name={"max_events"}
  path={"buffer"}
  relevantWhen={{"type":"memory"}}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum number of [events][docs.data-model] allowed in the buffer.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[104900000]}
  groups={[]}
  name={"max_size"}
  path={"buffer"}
  relevantWhen={{"type":"disk"}}
  required={true}
  templateable={false}
  type={"uint"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_size

The maximum size of the buffer on the disk.



</Field>
<Field
  common={true}
  defaultValue={"memory"}
  enumValues={{"memory":"Stores the sink's buffer in memory. This is more performant, but less durable. Data will be lost if Vector is restarted forcefully.","disk":"Stores the sink's buffer on disk. This is less performant, but durable. Data will not be lost between restarts."}}
  examples={["memory","disk"]}
  groups={[]}
  name={"type"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### type

The buffer's type and storage mechanism.



</Field>
<Field
  common={false}
  defaultValue={"block"}
  enumValues={{"block":"Applies back pressure when the buffer is full. This prevents data loss, but will cause data to pile up on the edge.","drop_newest":"Drops new data as it's received. This data is lost. This should be used when performance is the highest priority."}}
  examples={["block","drop_newest"]}
  groups={[]}
  name={"when_full"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### when_full

The behavior when the buffer becomes full.



</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={"gzip"}
  enumValues={{"none":"No compression.","gzip":"[Gzip][urls.gzip] standard DEFLATE compression."}}
  examples={["none","gzip"]}
  groups={[]}
  name={"compression"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### compression

The compression strategy used to compress the encoded event data before
transmission.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["gzip"]}
  groups={[]}
  name={"content_encoding"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### content_encoding

Specifies what content encodings have been applied to the object and thus what
decoding mechanisms must be applied to obtain the media-type referenced by the
Content-Type header field. By default calculated from [`compression`](#compression) value.



</Field>
<Field
  common={false}
  defaultValue={"text/x-log"}
  enumValues={null}
  examples={["text/x-log"]}
  groups={[]}
  name={"content_type"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### content_type

A standard MIME type describing the format of the contents.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"encoding"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### encoding

Configures the encoding specific sink behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={"text"}
  enumValues={{"ndjson":"Each event is encoded into JSON and the payload is new line delimited.","text":"Each event is encoded into text via the `message` key and the payload is new line delimited."}}
  examples={["ndjson","text"]}
  groups={[]}
  name={"codec"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### codec

The encoding codec used to serialize the events before outputting.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"except_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### except_fields

Prevent the sink from encoding the specified labels.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"only_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### only_fields

Limit the sink to only encoding the specified labels.



</Field>
<Field
  common={false}
  defaultValue={"rfc3339"}
  enumValues={{"rfc3339":"Format as an RFC3339 string","unix":"Format as a unix timestamp, can be parsed as a Clickhouse DateTime"}}
  examples={["rfc3339","unix"]}
  groups={[]}
  name={"timestamp_format"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### timestamp_format

How to format event timestamps.



</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["127.0.0.0:5000/path/to/service"]}
  groups={[]}
  name={"endpoint"}
  path={null}
  relevantWhen={{"region":""}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### endpoint

Custom endpoint for use with AWS-compatible services. Providing a value for
this option will make [`region`](#region) moot.



</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"filename_append_uuid"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### filename_append_uuid

Whether or not to append a UUID v4 token to the end of the file. This ensures
there are no name collisions high volume use cases.
 See [Object naming](#object-naming) for more info.


</Field>
<Field
  common={false}
  defaultValue={"log"}
  enumValues={null}
  examples={["log"]}
  groups={[]}
  name={"filename_extension"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### filename_extension

The filename extension to use in the object name.



</Field>
<Field
  common={false}
  defaultValue={"%s"}
  enumValues={null}
  examples={["%s"]}
  groups={[]}
  name={"filename_time_format"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### filename_time_format

The format of the resulting object file name. [`strftime`
specifiers][urls.strptime_specifiers] are supported.
 See [Object naming](#object-naming) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be","person@email.com","http://acs.amazonaws.com/groups/global/AllUsers"]}
  groups={[]}
  name={"grant_full_control"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### grant_full_control

Gives the named [grantee][urls.aws_s3_grantee] READ, READ_ACP, and WRITE_ACP
permissions on the created objects.
 See [Cross account object writing](#cross-account-object-writing) and [Object access control list (ACL)](#object-access-control-list-acl) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be","person@email.com","http://acs.amazonaws.com/groups/global/AllUsers"]}
  groups={[]}
  name={"grant_read"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### grant_read

Allows the named [grantee][urls.aws_s3_grantee] to read the created objects and
their metadata.
 See [Object access control list (ACL)](#object-access-control-list-acl) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be","person@email.com","http://acs.amazonaws.com/groups/global/AllUsers"]}
  groups={[]}
  name={"grant_read_acp"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### grant_read_acp

Allows the named [grantee][urls.aws_s3_grantee] to read the created objects'
ACL.
 See [Object access control list (ACL)](#object-access-control-list-acl) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["79a59df900b949e55d96a1e698fbacedfd6e09d98eacf8f8d5218e7cd47ef2be","person@email.com","http://acs.amazonaws.com/groups/global/AllUsers"]}
  groups={[]}
  name={"grant_write_acp"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### grant_write_acp

Allows the named [grantee][urls.aws_s3_grantee] to write the created objects'
ACL.
 See [Object access control list (ACL)](#object-access-control-list-acl) for more info.


</Field>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### healthcheck

Enables/disables the sink healthcheck upon start.
 See [Health Checks](#health-checks) for more info.


</Field>
<Field
  common={true}
  defaultValue={"date=%F/"}
  enumValues={null}
  examples={["date=%F/","date=%F/hour=%H/","year=%Y/month=%m/day=%d/","application_id={{ application_id }}/date=%F/"]}
  groups={[]}
  name={"key_prefix"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={true}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### key_prefix

A prefix to apply to all object key names. This should be used to partition
your objects, and it's important to end this value with a `/` if you want this
to be the root S3 "folder".
 See [Object naming](#object-naming), [Partitioning](#partitioning), and [Template Syntax](#template-syntax) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["us-east-1"]}
  groups={[]}
  name={"region"}
  path={null}
  relevantWhen={{"endpoint":""}}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### region

The [AWS region][urls.aws_regions] of the target service. If [`endpoint`](#endpoint) is
provided it will override this value since the endpoint includes the region.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### request

Configures the sink request behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={50}
  enumValues={null}
  examples={[50]}
  groups={[]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"requests"}
  warnings={[]}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={250}
  enumValues={null}
  examples={[250]}
  groups={[]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs)
time window.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={false}
  defaultValue={18446744073709551615}
  enumValues={null}
  examples={[18446744073709551615]}
  groups={[]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### retry_attempts

The maximum number of retries to make for failed requests. The default, for all
intents and purposes, represents an infinite number of retries.
 See [Retry Policy](#retry-policy) for more info.


</Field>
<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed
request. Once, the first retry has failed the fibonacci sequence will be used
to select future backoffs.



</Field>
<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.



</Field>
<Field
  common={true}
  defaultValue={30}
  enumValues={null}
  examples={[30]}
  groups={[]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly
recommended that you do not lower value below the service's internal timeout,
as this could create orphaned requests, pile on retries, and result in
duplicate data downstream.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={{"AES256":"256-bit Advanced Encryption Standard","aws:kms":"AWS managed key encryption"}}
  examples={["AES256","aws:kms"]}
  groups={[]}
  name={"server_side_encryption"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### server_side_encryption

The server-side encryption algorithm used when storing these objects.
 See [Server-side encryption (SSE)](#server-side-encryption-sse) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["abcd1234"]}
  groups={[]}
  name={"ssekms_key_id"}
  path={null}
  relevantWhen={{"server_side_encryption":"aws:kms"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### ssekms_key_id

If [`server_side_encryption`](#server_side_encryption) has the value `"aws.kms"`, this specifies the ID of
the AWS Key Management Service (AWS KMS) symmetrical customer managed customer
master key (CMK) that will used for the created objects. If not specified,
Amazon S3 uses the AWS managed CMK in AWS to protect the data.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={{"STANDARD":"The default storage class. If you don't specify the storage class when you upload an object, Amazon S3 assigns the STANDARD storage class.","REDUCED_REDUNDANCY":"Designed for noncritical, reproducible data that can be stored with less redundancy than the STANDARD storage class. AWS recommends that you not use this storage class. The STANDARD storage class is more cost effective. ","INTELLIGENT_TIERING":"Stores objects in two access tiers: one tier that is optimized for frequent access and another lower-cost tier that is optimized for infrequently accessed data.","STANDARD_IA":"Amazon S3 stores the object data redundantly across multiple geographically separated Availability Zones (similar to the STANDARD storage class).","ONEZONE_IA":"Amazon S3 stores the object data in only one Availability Zone.","GLACIER":"Use for archives where portions of the data might need to be retrieved in minutes.","DEEP_ARCHIVE":"Use for archiving data that rarely needs to be accessed."}}
  examples={["STANDARD","REDUCED_REDUNDANCY","INTELLIGENT_TIERING","STANDARD_IA","ONEZONE_IA","GLACIER","DEEP_ARCHIVE"]}
  groups={[]}
  name={"storage_class"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### storage_class

The storage class for the created objects. See [the S3 Storage
Classes](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html)
for more details.
 See [Storage class](#storage-class) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tags"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tags

The tag-set for the object.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[{"Tag1":"Value1"}]}
  groups={[]}
  name={"`[tag-name]`"}
  path={"tags"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[tag-name]`

A custom tag to be added to the created objects.



</Field>
</Fields>

</Field>
</Fields>

## Env Vars

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["AKIAIOSFODNN7EXAMPLE"]}
  groups={[]}
  name={"AWS_ACCESS_KEY_ID"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### AWS_ACCESS_KEY_ID

Used for AWS authentication when communicating with AWS services. See relevant
[AWS components][pages.aws_components] for more info.
 See [AWS Authentication](#aws-authentication) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["wJalrXUtnFEMI/K7MDENG/FD2F4GJ"]}
  groups={[]}
  name={"AWS_SECRET_ACCESS_KEY"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### AWS_SECRET_ACCESS_KEY

Used for AWS authentication when communicating with AWS services. See relevant
[AWS components][pages.aws_components] for more info.
 See [AWS Authentication](#aws-authentication) for more info.


</Field>
</Fields>


## How It Works

### AWS Authentication

Vector checks for AWS credentials in the following order:

1. Environment variables [`AWS_ACCESS_KEY_ID`](#aws_access_key_id) and [`AWS_SECRET_ACCESS_KEY`](#aws_secret_access_key).
2. The [`credential_process` command][urls.aws_credential_process] in the AWS config file. (usually located at `~/.aws/config`)
3. The [AWS credentials file][urls.aws_credentials_file]. (usually located at `~/.aws/credentials`)
4. The [IAM instance profile][urls.iam_instance_profile]. (will only work if running on an EC2 instance with an instance profile/role)

If credentials are not found the [healtcheck](#healthchecks) will fail and an
error will be [logged][docs.monitoring#logs].

#### Obtaining an access key

In general, we recommend using instance profiles/roles whenever possible. In
cases where this is not possible you can generate an AWS access key for any user
within your AWS account. AWS provides a [detailed guide][urls.aws_access_keys] on
how to do this.

#### Assuming Roles

Vector can assume an AWS IAM role via the [`assume_role`](#assume_role) option. This is an
optional setting that is helpful for a variety of use cases, such as cross
account access.

### Buffers & Batches

<SVG src="/img/buffers-and-batches-partitioned.svg" />

The `aws_s3` sink buffers & batches data as
shown in the diagram above. You'll notice that Vector treats these concepts
differently, instead of treating them as global concepts, Vector treats them
as sink specific concepts. This isolates sinks, ensuring services disruptions
are contained and [delivery guarantees][docs.guarantees] are honored.

*Batches* are flushed when 1 of 2 conditions are met:

1. The batch age meets or exceeds the configured [`timeout_secs`](#timeout_secs).
2. The batch size meets or exceeds the configured [`max_events`](#max_events).

*Buffers* are controlled via the [`buffer.*`](#buffer) options.

### Cross account object writing

If you're using Vector to write objects across AWS accounts then you should
consider setting the [`grant_full_control`](#grant_full_control) option to the bucket owner's
canonical user ID. AWS provides a
[full tutorial][urls.aws_s3_cross_account_tutorial] for this use case. If
don't know the bucket owner's canoncial ID you can find it by following
[this tutorial][urls.aws_canonical_user_id].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Object access control list (ACL)

AWS S3 supports [access control lists (ACL)][urls.aws_s3_acl] for buckets and
objects. In the context of Vector, only object ACLs are relevant (Vector does
not create or modify buckets). You can set the object level ACL by using one
of the [`acl`](#acl), [`grant_full_control`](#grant_full_control), [`grant_read`](#grant_read), [`grant_read_acp`](#grant_read_acp), or
`grant_write_acp` options.

#### [`acl`](#acl) vs the `grant_*` options

The `grant_*` options name a specific entity to grant access to. The [`acl`](#acl)
options is one of a set of [specific canned ACLs][urls.aws_s3_canned_acl] that
can only name the owner or world.

### Object naming

By default, Vector will name your S3 objects in the following format:

<Tabs
  block={true}
  defaultValue="without_compression"
  values={[
    { label: 'Without Compression', value: 'without_compression', },
    { label: 'With Compression', value: 'with_compression', },
  ]
}>

<TabItem value="without_compression">

```text
<key_prefix><timestamp>-<uuidv4>.log
```

For example:

```text
date=2019-06-18/1560886634-fddd7a0e-fad9-4f7e-9bce-00ae5debc563.log
```

</TabItem>
<TabItem value="with_compression">

```text
<key_prefix><timestamp>-<uuidv4>.log.gz
```

For example:

```text
date=2019-06-18/1560886634-fddd7a0e-fad9-4f7e-9bce-00ae5debc563.log.gz
```

</TabItem>
</Tabs>

Vector appends a [UUIDV4][urls.uuidv4] token to ensure there are no name
conflicts in the unlikely event 2 Vector instances are writing data at the same
time.

You can control the resulting name via the [`key_prefix`](#key_prefix), [`filename_time_format`](#filename_time_format),
and [`filename_append_uuid`](#filename_append_uuid) options.

### Partitioning

Partitioning is controlled via the [`key_prefix`](#key_prefix)
options and allows you to dynamically partition data on the fly.
You'll notice that Vector's [template sytax][docs.reference.templating] is
supported for these options, enabling you to use field values as partition keys.

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issue][urls.new_aws_s3_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.

### Server-side encryption (SSE)

AWS S3 offers [server-side encryption][urls.aws_s3_sse]. You can apply defaults
at the bucket level or set the encryption at the object level. In the context,
of Vector only the object level is relevant (Vector does not create or modify
buckets). Although, we recommend setting defaults at the bucket level whne
possible. You can explicitly set the object level encryption via the
`server_side_encryption` option.

### Storage class

AWS S3 offers [storage classes][urls.aws_s3_storage_classes]. You can apply
defaults, and rules, at the bucket level or set the storage class at the object
level. In the context of Vector only the object level is relevant (Vector does
not create or modify buckets). You can set the storage class via the
`storage_class` option.

### Tags & metadata

Vector currently only supports [AWS S3 object tags][urls.aws_s3_tags] and does
_not_ support [object metadata][urls.aws_s3_metadata]. If you require metadata
support see [issue #1694][urls.issue_1694].

We believe tags are more flexible since they are separate from the actual S3
object. Youc an freely modify tags without modifying the object. Conversely,
object metadata requires a full rewrite of the object to make changes.


### Template Syntax

The [`key_prefix`](#key_prefix) options
support [Vector's template syntax][docs.reference.templating], enabling dynamic
values derived from the event's data. This syntax accepts
[strptime specifiers][urls.strptime_specifiers] as well as the
`{{ field_name }}` syntax for accessing event fields. For example:

```toml title="vector.toml"
[sinks.my_aws_s3_sink_id]
  # ...
  key_prefix = "date=%F/"
  key_prefix = "date=%F/hour=%H/"
  key_prefix = "year=%Y/month=%m/day=%d/"
  key_prefix = "application_id={{ application_id }}/date=%F/"
  # ...
```

You can learn more about the complete syntax in the
[templating reference][docs.reference.templating].

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model]: /docs/about/data-model/
[docs.guarantees]: /docs/about/guarantees/
[docs.monitoring#logs]: /docs/administration/monitoring/#logs
[docs.reference.templating]: /docs/reference/templating/
[pages.aws_components]: /components/?providers%5B%5D=aws/
[urls.aws_access_keys]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html
[urls.aws_canonical_user_id]: https://docs.aws.amazon.com/general/latest/gr/acct-identifiers.html#FindingCanonicalId
[urls.aws_credential_process]: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sourcing-external.html
[urls.aws_credentials_file]: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html
[urls.aws_iam_role]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html
[urls.aws_regions]: https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.RegionsAndAvailabilityZones.html
[urls.aws_s3]: https://aws.amazon.com/s3/
[urls.aws_s3_acl]: https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html
[urls.aws_s3_canned_acl]: https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#canned-acl
[urls.aws_s3_cross_account_tutorial]: https://docs.aws.amazon.com/AmazonS3/latest/dev/example-walkthroughs-managing-access-example3.html
[urls.aws_s3_grantee]: https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#specifying-grantee
[urls.aws_s3_metadata]: https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingMetadata.html#object-metadata
[urls.aws_s3_sse]: https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingServerSideEncryption.html
[urls.aws_s3_storage_classes]: https://aws.amazon.com/s3/storage-classes/
[urls.aws_s3_tags]: https://docs.aws.amazon.com/AmazonS3/latest/user-guide/add-object-tags.html
[urls.gzip]: https://www.gzip.org/
[urls.iam_instance_profile]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html
[urls.issue_1694]: https://github.com/timberio/vector/issues/1694
[urls.new_aws_s3_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+aws_s3
[urls.strptime_specifiers]: https://docs.rs/chrono/0.4.11/chrono/format/strftime/index.html#specifiers
[urls.uuidv4]: https://en.wikipedia.org/wiki/Universally_unique_identifier#Version_4_(random)
