---
last_modified_on: "2020-07-13"
delivery_guarantee: "at_least_once"
component_title: "Elasticsearch"
description: "The Vector `elasticsearch` sink batches `log` events to Elasticsearch via the `_bulk` API endpoint."
event_types: ["log"]
function_category: "transmit"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+elasticsearch%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "elasticsearch|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sinks/elasticsearch.rs
status: "prod-ready"
title: "Elasticsearch Sink"
unsupported_operating_systems: []
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import SVG from 'react-inlinesvg';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `elasticsearch` sink
[batches](#buffers--batches) [`log`][docs.data-model.log] events to
[Elasticsearch][urls.elasticsearch] via the [`_bulk` API
endpoint][urls.elasticsearch_bulk].

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/elasticsearch.md.erb
-->

## Warnings

<Alert icon={false} type="warning" className="list--icons list--icons--warnings">

* [`compression`](#compression) - AWS hosted Elasticsearch is unable to use compression

</Alert>

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sinks.my_sink_id]
  type = "elasticsearch" # required
  inputs = ["my-source-or-transform-id"] # required
  compression = "none" # optional, default
  healthcheck = true # optional, default
  host = "http://10.24.32.122:9000" # optional, no default
  index = "vector-%F" # optional, default
  pipeline = "pipeline-name" # optional, no default
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sinks.my_sink_id]
  # General
  type = "elasticsearch" # required
  inputs = ["my-source-or-transform-id"] # required
  compression = "none" # optional, default
  doc_type = "_doc" # optional, default
  healthcheck = true # optional, default
  host = "http://10.24.32.122:9000" # optional, no default
  id_key = "id" # optional, no default
  index = "vector-%F" # optional, default
  pipeline = "pipeline-name" # optional, no default

  # Auth
  auth.assume_role = "arn:aws:iam::123456789098:role/my_role" # optional, no default, relevant when strategy = "aws"
  auth.password = "${ELASTICSEARCH_PASSWORD}" # required, required when strategy = "basic"
  auth.strategy = "aws" # required
  auth.user = "${ELASTICSEARCH_USERNAME}" # required, required when strategy = "basic"

  # AWS
  aws.region = "us-east-1" # optional, no default, relevant when strategy = "aws"

  # Batch
  batch.max_bytes = 10490000 # optional, default, bytes
  batch.max_events = 1000 # optional, no default, events
  batch.timeout_secs = 1 # optional, default, seconds

  # Buffer
  buffer.max_events = 500 # optional, default, events, relevant when type = "memory"
  buffer.max_size = 104900000 # required, bytes, required when type = "disk"
  buffer.type = "memory" # optional, default
  buffer.when_full = "block" # optional, default

  # Encoding
  encoding.except_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.only_fields = ["timestamp", "message", "host"] # optional, no default
  encoding.timestamp_format = "rfc3339" # optional, default

  # Headers
  headers.Authorization = "${ELASTICSEARCH_TOKEN}" # example
  headers.X-Powered-By = "Vector" # example

  # Query
  query.X-Powered-By = "Vector" # example

  # Request
  request.in_flight_limit = 5 # optional, default, requests
  request.rate_limit_duration_secs = 1 # optional, default, seconds
  request.rate_limit_num = 5 # optional, default
  request.retry_attempts = 18446744073709551615 # optional, default
  request.retry_initial_backoff_secs = 1 # optional, default, seconds
  request.retry_max_duration_secs = 10 # optional, default, seconds
  request.timeout_secs = 60 # optional, default, seconds

  # TLS
  tls.ca_file = "/path/to/certificate_authority.crt" # optional, no default
  tls.crt_file = "/path/to/host_certificate.crt" # optional, no default
  tls.key_file = "/path/to/host_certificate.key" # optional, no default
  tls.key_pass = "${KEY_PASS_ENV_VAR}" # optional, no default
  tls.verify_certificate = true # optional, default
  tls.verify_hostname = true # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"auth"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### auth

Options for the authentication strategy.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["arn:aws:iam::123456789098:role/my_role"]}
  groups={[]}
  name={"assume_role"}
  path={"auth"}
  relevantWhen={{"strategy":"aws"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### assume_role

The ARN of an [IAM role][urls.aws_iam_role] to assume at startup.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${ELASTICSEARCH_PASSWORD}","password"]}
  groups={[]}
  name={"password"}
  path={"auth"}
  relevantWhen={{"strategy":"basic"}}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### password

The basic authentication password.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"aws":"Authentication strategy used for [AWS' hosted Elasticsearch service][urls.aws_elasticsearch].","basic":"The [basic authentication strategy][urls.basic_auth]."}}
  examples={["aws","basic"]}
  groups={[]}
  name={"strategy"}
  path={"auth"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### strategy

The authentication strategy to use.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${ELASTICSEARCH_USERNAME}","username"]}
  groups={[]}
  name={"user"}
  path={"auth"}
  relevantWhen={{"strategy":"basic"}}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### user

The basic authentication user name.



</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"aws"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### aws

Options for the AWS connections.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["us-east-1"]}
  groups={[]}
  name={"region"}
  path={"aws"}
  relevantWhen={{"strategy":"aws"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### region

The [AWS region][urls.aws_regions] of the target service. This defaults to the
region named in the host parameter, or the value of the `$AWS_REGION` or
`$AWS_DEFAULT_REGION` environment variables if that cannot be determined, or
"us-east-1".



</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### batch

Configures the sink batching behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={10490000}
  enumValues={null}
  examples={[10490000]}
  groups={[]}
  name={"max_bytes"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_bytes

The maximum size of a batch, in bytes, before it is flushed.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[1000]}
  groups={[]}
  name={"max_events"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum size of a batch, in events, before it is flushed.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum age of a batch before it is flushed.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"buffer"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### buffer

Configures the sink specific buffer behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={500}
  enumValues={null}
  examples={[500]}
  groups={[]}
  name={"max_events"}
  path={"buffer"}
  relevantWhen={{"type":"memory"}}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"events"}
  warnings={[]}
  >

#### max_events

The maximum number of [events][docs.data-model] allowed in the buffer.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[104900000]}
  groups={[]}
  name={"max_size"}
  path={"buffer"}
  relevantWhen={{"type":"disk"}}
  required={true}
  templateable={false}
  type={"uint"}
  unit={"bytes"}
  warnings={[]}
  >

#### max_size

The maximum size of the buffer on the disk.



</Field>
<Field
  common={true}
  defaultValue={"memory"}
  enumValues={{"memory":"Stores the sink's buffer in memory. This is more performant, but less durable. Data will be lost if Vector is restarted forcefully.","disk":"Stores the sink's buffer on disk. This is less performant, but durable. Data will not be lost between restarts."}}
  examples={["memory","disk"]}
  groups={[]}
  name={"type"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### type

The buffer's type and storage mechanism.



</Field>
<Field
  common={false}
  defaultValue={"block"}
  enumValues={{"block":"Applies back pressure when the buffer is full. This prevents data loss, but will cause data to pile up on the edge.","drop_newest":"Drops new data as it's received. This data is lost. This should be used when performance is the highest priority."}}
  examples={["block","drop_newest"]}
  groups={[]}
  name={"when_full"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### when_full

The behavior when the buffer becomes full.



</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={"none"}
  enumValues={{"none":"No compression.","gzip":"[Gzip][urls.gzip] standard DEFLATE compression."}}
  examples={["none","gzip"]}
  groups={[]}
  name={"compression"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[{"visibility_level":"component","text":"AWS hosted Elasticsearch is unable to use compression","option_name":"compression"}]}
  >

### compression

The compression strategy used to compress the encoded event data before
transmission.



</Field>
<Field
  common={false}
  defaultValue={"_doc"}
  enumValues={null}
  examples={["_doc"]}
  groups={[]}
  name={"doc_type"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### doc_type

The [`doc_type`](#doc_type) for your index data. This is only relevant for Elasticsearch <=
6.X. If you are using >= 7.0 you do not need to set this option since
Elasticsearch has removed it.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"encoding"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### encoding

Configures the encoding specific sink behavior.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"except_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### except_fields

Prevent the sink from encoding the specified labels.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","message","host"]]}
  groups={[]}
  name={"only_fields"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

#### only_fields

Limit the sink to only encoding the specified labels.



</Field>
<Field
  common={false}
  defaultValue={"rfc3339"}
  enumValues={{"rfc3339":"Format as an RFC3339 string","unix":"Format as a unix timestamp, can be parsed as a Clickhouse DateTime"}}
  examples={["rfc3339","unix"]}
  groups={[]}
  name={"timestamp_format"}
  path={"encoding"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### timestamp_format

How to format event timestamps.



</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"headers"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### headers

Options for custom headers.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"Authorization":"${ELASTICSEARCH_TOKEN}"},{"X-Powered-By":"Vector"}]}
  groups={[]}
  name={"`[header-name]`"}
  path={"headers"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[header-name]`

A custom header to be added to each outgoing Elasticsearch request.



</Field>
</Fields>

</Field>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### healthcheck

Enables/disables the sink healthcheck upon start.
 See [Health Checks](#health-checks) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["http://10.24.32.122:9000"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### host

The host of your Elasticsearch cluster. This should be the full URL as shown in
the example.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["id","_id"]}
  groups={[]}
  name={"id_key"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### id_key

The name of the event key that should map to Elasticsearch's [`_id`
field][urls.elasticsearch_id_field]. By default, Vector does not set the `_id`
field, which allows Elasticsearch to set this automatically. You should think
carefully about setting your own Elasticsearch IDs, since this can [hinder
perofrmance][urls.elasticsearch_id_performance].



</Field>
<Field
  common={true}
  defaultValue={"vector-%F"}
  enumValues={null}
  examples={["application-{{ application_id }}-%Y-%m-%d","vector-%Y-%m-%d"]}
  groups={[]}
  name={"index"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={true}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### index

Index name to write events to.
 See [Document Conflicts](#document-conflicts) and [Template Syntax](#template-syntax) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["pipeline-name"]}
  groups={[]}
  name={"pipeline"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### pipeline

Name of the pipeline to apply.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"query"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### query

Custom parameters to Elasticsearch query string.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"X-Powered-By":"Vector"}]}
  groups={[]}
  name={"`[parameter-name]`"}
  path={"query"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[parameter-name]`

A custom parameter to be added to each Elasticsearch request.



</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### request

Configures the sink request behavior.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"requests"}
  warnings={[]}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={true}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs)
time window.
 See [Rate Limits](#rate-limits) for more info.


</Field>
<Field
  common={false}
  defaultValue={18446744073709551615}
  enumValues={null}
  examples={[18446744073709551615]}
  groups={[]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

#### retry_attempts

The maximum number of retries to make for failed requests. The default, for all
intents and purposes, represents an infinite number of retries.
 See [Retry Policy](#retry-policy) for more info.


</Field>
<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed
request. Once, the first retry has failed the fibonacci sequence will be used
to select future backoffs.



</Field>
<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.



</Field>
<Field
  common={true}
  defaultValue={60}
  enumValues={null}
  examples={[60]}
  groups={[]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly
recommended that you do not lower value below the service's internal timeout,
as this could create orphaned requests, pile on retries, and result in
duplicate data downstream.
 See [Buffers & Batches](#buffers--batches) for more info.


</Field>
</Fields>

</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tls"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tls

Configures the TLS options for connections from this sink.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/certificate_authority.crt"]}
  groups={[]}
  name={"ca_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### ca_file

Absolute path to an additional CA certificate file, in DER or PEM format
(X.509), or an inline CA certificate in PEM format.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.crt"]}
  groups={[]}
  name={"crt_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### crt_file

Absolute path to a certificate file used to identify this connection, in DER or
PEM format (X.509) or PKCS#12, or an inline certificate in PEM format. If this
is set and is not a PKCS#12 archive, [`key_file`](#key_file) must also be set.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.key"]}
  groups={[]}
  name={"key_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_file

Absolute path to a private key file used to identify this connection, in DER or
PEM format (PKCS#8), or an inline private key in PEM format. If this is set,
`crt_file` must also be set.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["${KEY_PASS_ENV_VAR}","PassWord1"]}
  groups={[]}
  name={"key_pass"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_pass

Pass phrase used to unlock the encrypted key file. This has no effect unless
`key_file` is set.



</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_certificate"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[{"visibility_level":"option","text":"Setting this to `false` means the certificate will be loaded and checked for validity, but the handshake will not attempt to verify the certificate. Do NOT set this to `false` unless you understand the risks of not verifying the remote certificate.","option_name":"verify_certificate"}]}
  >

#### verify_certificate

If `true` (the default), Vector will validate the TLS certificate of the remote
host.



</Field>
<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_hostname"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

#### verify_hostname

If `true` (the default), Vector will validate the configured remote host name
against the remote host's TLS certificate. Do NOT set this to `false` unless
you understand the risks of not verifying the remote hostname.



</Field>
</Fields>

</Field>
</Fields>

## Env Vars

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["AKIAIOSFODNN7EXAMPLE"]}
  groups={[]}
  name={"AWS_ACCESS_KEY_ID"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### AWS_ACCESS_KEY_ID

Used for AWS authentication when communicating with AWS services. See relevant
[AWS components][pages.aws_components] for more info.
 See [AWS Authentication](#aws-authentication) for more info.


</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["wJalrXUtnFEMI/K7MDENG/FD2F4GJ"]}
  groups={[]}
  name={"AWS_SECRET_ACCESS_KEY"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### AWS_SECRET_ACCESS_KEY

Used for AWS authentication when communicating with AWS services. See relevant
[AWS components][pages.aws_components] for more info.
 See [AWS Authentication](#aws-authentication) for more info.


</Field>
</Fields>


## Examples

```http
POST <host>/_bulk HTTP/1.1
Host: <host>
Content-Type: application/x-ndjson
Content-Length: <byte_size>

{ "index" : { "_index" : "<index>" } }
<json_encoded_log>
{ "index" : { "_index" : "<index>" } }
<json_encoded_log>
{ "index" : { "_index" : "<index>" } }
<json_encoded_log>
```

## How It Works

### AWS Authentication

Vector checks for AWS credentials in the following order:

1. Environment variables [`AWS_ACCESS_KEY_ID`](#aws_access_key_id) and [`AWS_SECRET_ACCESS_KEY`](#aws_secret_access_key).
2. The [`credential_process` command][urls.aws_credential_process] in the AWS config file. (usually located at `~/.aws/config`)
3. The [AWS credentials file][urls.aws_credentials_file]. (usually located at `~/.aws/credentials`)
4. The [IAM instance profile][urls.iam_instance_profile]. (will only work if running on an EC2 instance with an instance profile/role)

If credentials are not found the [healtcheck](#healthchecks) will fail and an
error will be [logged][docs.monitoring#logs].

#### Obtaining an access key

In general, we recommend using instance profiles/roles whenever possible. In
cases where this is not possible you can generate an AWS access key for any user
within your AWS account. AWS provides a [detailed guide][urls.aws_access_keys] on
how to do this.

### Buffers & Batches

<SVG src="/img/buffers-and-batches-serial.svg" />

The `elasticsearch` sink buffers & batches data as
shown in the diagram above. You'll notice that Vector treats these concepts
differently, instead of treating them as global concepts, Vector treats them
as sink specific concepts. This isolates sinks, ensuring services disruptions
are contained and [delivery guarantees][docs.guarantees] are honored.

*Batches* are flushed when 1 of 2 conditions are met:

1. The batch age meets or exceeds the configured [`timeout_secs`](#timeout_secs).
2. The batch size meets or exceeds the configured [`max_events`](#max_events).

*Buffers* are controlled via the [`buffer.*`](#buffer) options.

### Document Conflicts

Vector [batches](#buffers--batches) data flushes it to Elasticsearch's
[`_bulk` API endpoint][urls.elasticsearch_bulk]. All events are inserted
via the [`index`](#index) action. Which, in the case of an conflict (document with the
same [`id`](#id)), will add or _replace_ the document as necessary.



### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### GCP Authentication

GCP offers a [variety of authentication methods][urls.gcp_authentication] and
Vector is concerned with the [server to server methods][urls.gcp_authentication_server_to_server]
and will find credentials in the following order:

1. If the `credentials_path` option is set.
1. If the `GOOGLE_APPLICATION_CREDENTIALS` envrionment variable is set.
1. Finally, Vector will check for an [instance service account][urls.gcp_authentication_service_account].

If credentials are not found the [healtcheck](#healthchecks) will fail and an
error will be [logged][docs.monitoring#logs].


### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issue][urls.new_elasticsearch_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.

### TLS

Vector uses [Openssl][urls.openssl] for TLS protocols for it's battle-tested
and reliable security. You can enable and adjust TLS behavior via the [`tls.*`](#tls)
options.

### Template Syntax

The [`index`](#index) options
support [Vector's template syntax][docs.reference.templating], enabling dynamic
values derived from the event's data. This syntax accepts
[strptime specifiers][urls.strptime_specifiers] as well as the
`{{ field_name }}` syntax for accessing event fields. For example:

```toml title="vector.toml"
[sinks.my_elasticsearch_sink_id]
  # ...
  index = "application-{{ application_id }}-%Y-%m-%d"
  index = "vector-%Y-%m-%d"
  # ...
```

You can learn more about the complete syntax in the
[templating reference][docs.reference.templating].

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model]: /docs/about/data-model/
[docs.guarantees]: /docs/about/guarantees/
[docs.monitoring#logs]: /docs/administration/monitoring/#logs
[docs.reference.templating]: /docs/reference/templating/
[pages.aws_components]: /components/?providers%5B%5D=aws/
[urls.aws_access_keys]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html
[urls.aws_credential_process]: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sourcing-external.html
[urls.aws_credentials_file]: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html
[urls.aws_elasticsearch]: https://aws.amazon.com/elasticsearch-service/
[urls.aws_iam_role]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html
[urls.aws_regions]: https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.RegionsAndAvailabilityZones.html
[urls.basic_auth]: https://en.wikipedia.org/wiki/Basic_access_authentication
[urls.elasticsearch]: https://www.elastic.co/products/elasticsearch
[urls.elasticsearch_bulk]: https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-bulk.html
[urls.elasticsearch_id_field]: https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-id-field.html
[urls.elasticsearch_id_performance]: https://www.elastic.co/guide/en/elasticsearch/reference/master/tune-for-indexing-speed.html#_use_auto_generated_ids
[urls.gcp_authentication]: https://cloud.google.com/docs/authentication/
[urls.gcp_authentication_server_to_server]: https://cloud.google.com/docs/authentication/production
[urls.gcp_authentication_service_account]: https://cloud.google.com/docs/authentication/production#obtaining_and_providing_service_account_credentials_manually
[urls.gzip]: https://www.gzip.org/
[urls.iam_instance_profile]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html
[urls.new_elasticsearch_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+elasticsearch
[urls.openssl]: https://www.openssl.org/
[urls.strptime_specifiers]: https://docs.rs/chrono/0.4.11/chrono/format/strftime/index.html#specifiers
