---
last_modified_on: "2020-07-13"
delivery_guarantee: "at_least_once"
component_title: "Prometheus"
description: "The Vector `prometheus` source ingests data through the Prometheus text exposition format and outputs `metric` events."
event_types: ["metric"]
function_category: "receive"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+prometheus%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "prometheus|[\"metric\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/prometheus
status: "beta"
title: "Prometheus Source"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `prometheus` source
ingests data through the [Prometheus text exposition
format][urls.prometheus_text_based_exposition_format] and outputs
[`metric`][docs.data-model.metric] events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/prometheus.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sources.my_source_id]
  type = "prometheus" # required
  hosts = ["http://localhost:9090"] # required
  scrape_interval_secs = 15 # optional, default, seconds
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sources.my_source_id]
  type = "prometheus" # required
  hosts = ["http://localhost:9090"] # required
  scrape_interval_secs = 15 # optional, default, seconds
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["http://localhost:9090"]]}
  groups={[]}
  name={"hosts"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### hosts

Host addresses to scrape metrics from.



</Field>
<Field
  common={true}
  defaultValue={15}
  enumValues={null}
  examples={[15]}
  groups={[]}
  name={"scrape_interval_secs"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

### scrape_interval_secs

The interval between scrapes, in seconds.



</Field>
</Fields>

## Examples

<Tabs
  block={true}
  defaultValue="counter"
  select={false}
  values={[{"label":"Counter","value":"counter"},{"label":"Gauge","value":"gauge"}]}>

<TabItem value="counter">

Given the following input:

```text title="Example input"
# TYPE promhttp_metric_handler_requests_total counter
promhttp_metric_handler_requests_total{code="200"} 100
```

A metric event will be output with the following structure:

```json title="Example metric event"
{
  "name": "promhttp_metric_handler_requests_total",
  "kind": "absolute",
  "timestamp": "2019-05-02T12:22:46.658503Z" // current time / time ingested
  "tags": {
    "code": "200"
  },
  "value": {
    "type": "counter",
    "value": 100.0
  }
}
```

</TabItem>

<TabItem value="gauge">

Given the following input:

```text title="Example input"
prometheus_remote_storage_samples_in_total 57011636
```

A metric event will be output with the following structure:

```jsontitle="Example log event"
{
  "name": "prometheus_remote_storage_samples_in_total",
  "kind": "absolute",
  "timestamp": "2019-05-02T12:22:46.658503Z" // current time / time ingested
  "tags": null,
  "value": {
    "type": "gauge",
    "value": 57011636.0
  }
}
```

</TabItem>
</Tabs>

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.metric]: /docs/about/data-model/metric/
[urls.prometheus_text_based_exposition_format]: https://github.com/prometheus/docs/blob/master/content/docs/instrumenting/exposition_formats.md#text-based-format
