---
last_modified_on: "2020-07-13"
delivery_guarantee: "best_effort"
component_title: "Socket"
description: "The Vector `socket` source ingests data through a socket, such as a TCP, UDP, or UDS socket and outputs `log` events."
event_types: ["log"]
function_category: "receive"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+socket%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "socket|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/socket
status: "prod-ready"
title: "Socket Source"
unsupported_operating_systems: []
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `socket` source
ingests data through a [socket][urls.socket], such as a [TCP][urls.tcp],
[UDP][urls.udp], or [UDS][urls.uds] socket and outputs
[`log`][docs.data-model.log] events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/socket.md.erb
-->

## Requirements

<Alert icon={false} type="danger" className="list--icons list--icons--warnings">

* This component exposes a configured port. You must ensure your network allows access to this port.

</Alert>

## Configuration

<Tabs
  block={true}
  defaultValue="tcp"
  values={[{"label":"tcp","value":"tcp"},{"label":"tcp (adv)","value":"tcp-adv"},{"label":"udp","value":"udp"},{"label":"udp (adv)","value":"udp-adv"},{"label":"unix","value":"unix"},{"label":"unix (adv)","value":"unix-adv"}]}>
<TabItem value="tcp">

```toml title="vector.toml"
[sources.my_source_id]
  type = "socket" # required
  address = "0.0.0.0:9000" # required, required when mode = "tcp" or mode = "udp"
  max_length = 102400 # optional, default, bytes, relevant when mode = "tcp" or mode = "unix"
  mode = "tcp" # required
```

</TabItem>
<TabItem value="tcp-adv">

```toml title="vector.toml"
[sources.my_source_id]
  # General
  type = "socket" # required
  address = "0.0.0.0:9000" # required, required when mode = "tcp" or mode = "udp"
  max_length = 102400 # optional, default, bytes, relevant when mode = "tcp" or mode = "unix"
  mode = "tcp" # required
  shutdown_timeout_secs = 30 # optional, default, seconds, relevant when mode = "tcp"

  # Context
  host_key = "host" # optional, default

  # TLS
  tls.ca_file = "/path/to/certificate_authority.crt" # optional, no default, relevant when mode = "tcp"
  tls.crt_file = "/path/to/host_certificate.crt" # optional, no default, relevant when mode = "tcp"
  tls.enabled = false # optional, default, relevant when mode = "tcp"
  tls.key_file = "/path/to/host_certificate.key" # optional, no default, relevant when mode = "tcp"
  tls.key_pass = "${KEY_PASS_ENV_VAR}" # optional, no default, relevant when mode = "tcp"
  tls.verify_certificate = false # optional, default, relevant when mode = "tcp"
```

</TabItem>
<TabItem value="udp">

```toml title="vector.toml"
[sources.my_source_id]
  type = "socket" # required
  address = "0.0.0.0:9000" # required, required when mode = "tcp" or mode = "udp"
  mode = "udp" # required
```

</TabItem>
<TabItem value="udp-adv">

```toml title="vector.toml"
[sources.my_source_id]
  # General
  type = "socket" # required
  address = "0.0.0.0:9000" # required, required when mode = "tcp" or mode = "udp"
  mode = "udp" # required

  # Context
  host_key = "host" # optional, default
```

</TabItem>
<TabItem value="unix">

```toml title="vector.toml"
[sources.my_source_id]
  type = "socket" # required
  max_length = 102400 # optional, default, bytes, relevant when mode = "tcp" or mode = "unix"
  mode = "unix" # required
  path = "/path/to/socket" # required, required when mode = "unix"
```

</TabItem>
<TabItem value="unix-adv">

```toml title="vector.toml"
[sources.my_source_id]
  # General
  type = "socket" # required
  max_length = 102400 # optional, default, bytes, relevant when mode = "tcp" or mode = "unix"
  mode = "unix" # required
  path = "/path/to/socket" # required, required when mode = "unix"

  # Context
  host_key = "host" # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["0.0.0.0:9000","systemd","systemd#3"]}
  groups={["tcp","udp"]}
  name={"address"}
  path={null}
  relevantWhen={{"mode":["tcp","udp"]}}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### address

The address to listen for connections on, or `systemd#N` to use the Nth socket
passed by systemd socket activation. If an address is used it _must_ include a
port.



</Field>
<Field
  common={false}
  defaultValue={"host"}
  enumValues={null}
  examples={["host"]}
  groups={["tcp","udp","unix"]}
  name={"host_key"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### host_key

The key name added to each event representing the current host. This can also
be globally set via the [global [`host_key`](#host_key)
option][docs.reference.global-options#host_key].
 See [Context](#context) for more info.


</Field>
<Field
  common={true}
  defaultValue={102400}
  enumValues={null}
  examples={[102400]}
  groups={["tcp","unix"]}
  name={"max_length"}
  path={null}
  relevantWhen={{"mode":["tcp","unix"]}}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"bytes"}
  warnings={[]}
  >

### max_length

The maximum bytes size of incoming messages before they are discarded.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"tcp":"TCP Socket.","udp":"UDP Socket.","unix":"Unix Domain Socket."}}
  examples={["tcp","udp","unix"]}
  groups={["tcp","udp","unix"]}
  name={"mode"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### mode

The type of socket to use.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/socket"]}
  groups={["unix"]}
  name={"path"}
  path={null}
  relevantWhen={{"mode":"unix"}}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### path

The unix socket path. *This should be absolute path*.



</Field>
<Field
  common={false}
  defaultValue={30}
  enumValues={null}
  examples={[30]}
  groups={["tcp"]}
  name={"shutdown_timeout_secs"}
  path={null}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

### shutdown_timeout_secs

The timeout before a connection is forcefully closed during shutdown.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={["tcp"]}
  name={"tls"}
  path={null}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tls

Configures the TLS options for connections from this source.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/certificate_authority.crt"]}
  groups={["tcp"]}
  name={"ca_file"}
  path={"tls"}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### ca_file

Absolute path to an additional CA certificate file, in DER or PEM format
(X.509), or an inline CA certificate in PEM format.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.crt"]}
  groups={["tcp"]}
  name={"crt_file"}
  path={"tls"}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### crt_file

Absolute path to a certificate file used to identify this server, in DER or PEM
format (X.509) or PKCS#12, or an inline certificate in PEM format. If this is
set and is not a PKCS#12 archive, [`key_file`](#key_file) must also be set. This is required
if [`enabled`](#enabled) is set to `true`.



</Field>
<Field
  common={true}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={["tcp"]}
  name={"enabled"}
  path={"tls"}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

#### enabled

Require TLS for incoming connections. If this is set, an identity certificate
is also required.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.key"]}
  groups={["tcp"]}
  name={"key_file"}
  path={"tls"}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_file

Absolute path to a private key file used to identify this server, in DER or PEM
format (PKCS#8), or an inline private key in PEM format.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${KEY_PASS_ENV_VAR}","PassWord1"]}
  groups={["tcp"]}
  name={"key_pass"}
  path={"tls"}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_pass

Pass phrase used to unlock the encrypted key file. This has no effect unless
`key_file` is set.



</Field>
<Field
  common={false}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={["tcp"]}
  name={"verify_certificate"}
  path={"tls"}
  relevantWhen={{"mode":"tcp"}}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[{"visibility_level":"option","text":"Setting this to `false` will cause OpenSSL to not request a certificate from the client","option_name":"verify_certificate"}]}
  >

#### verify_certificate

If `true`, Vector will require a TLS certificate from the connecting host and
terminate the connection if it is not valid. If `false` (the default), Vector
will not request a certificate from the client.



</Field>
</Fields>

</Field>
</Fields>

## Fields

```javascript title="example log event"
{
  // ...
  "host": "my.host.com",
  "message": "Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100",
  "timestamp": "2019-11-01T21:15:47+00:00"
  // ...
}
```

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["my.host.com"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### host

The upstream hostname.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["Started GET / for 127.0.0.1 at 2012-03-10 14:28:14 +0100"]}
  groups={[]}
  name={"message"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### message

The raw message, unaltered.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  groups={[]}
  name={"timestamp"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"timestamp"}
  unit={null}
  warnings={[]}
  >

### timestamp

The exact time the event was ingested.



</Field>
</Fields>

## Examples

Given the following input line:

```text title="Example input"
2019-02-13T19:48:34+00:00 [info] Started GET "/" for 127.0.0.1
```

A log event will be output with the following structure:

```json title="Example log event"
{
  "timestamp": <current_timestamp>,
  "message": "2019-02-13T19:48:34+00:00 [info] Started GET "/" for 127.0.0.1",
  "host": "<upstream_hostname>"
}
```

## How It Works

### Context

By default, the `socket` source will add context
keys to your events via the [`host_key`](#host_key)
options.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### TLS

Vector uses [Openssl][urls.openssl] for TLS protocols for it's battle-tested
and reliable security. You can enable and adjust TLS behavior via the [`tls.*`](#tls)
options.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.global-options#host_key]: /docs/reference/global-options/#host_key
[urls.openssl]: https://www.openssl.org/
[urls.socket]: https://en.wikipedia.org/wiki/Network_socket
[urls.tcp]: https://en.wikipedia.org/wiki/Transmission_Control_Protocol
[urls.udp]: https://en.wikipedia.org/wiki/User_Datagram_Protocol
[urls.uds]: https://en.wikipedia.org/wiki/Unix_domain_socket
