---
last_modified_on: "2020-07-13"
delivery_guarantee: "best_effort"
component_title: "Vector"
description: "The Vector `vector` source ingests data through another upstream `vector` sink and outputs `log` and `metric` events."
event_types: ["log","metric"]
function_category: "receive"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+vector%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "vector|[\"log\",\"metric\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/vector.rs
status: "beta"
title: "Vector Source"
unsupported_operating_systems: []
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `vector` source
ingests data through another upstream [`vector` sink][docs.sinks.vector] and
outputs [`log`][docs.data-model.log] and [`metric`][docs.data-model.metric]
events.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/vector.md.erb
-->

## Requirements

<Alert icon={false} type="danger" className="list--icons list--icons--warnings">

* This component exposes a configured port. You must ensure your network allows access to this port.

</Alert>

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[sources.my_source_id]
  type = "vector" # required
  address = "0.0.0.0:9000" # required
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[sources.my_source_id]
  # General
  type = "vector" # required
  address = "0.0.0.0:9000" # required
  shutdown_timeout_secs = 30 # optional, default, seconds

  # TLS
  tls.ca_file = "/path/to/certificate_authority.crt" # optional, no default
  tls.crt_file = "/path/to/host_certificate.crt" # optional, no default
  tls.enabled = false # optional, default
  tls.key_file = "/path/to/host_certificate.key" # optional, no default
  tls.key_pass = "${KEY_PASS_ENV_VAR}" # optional, no default
  tls.verify_certificate = false # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["0.0.0.0:9000","systemd","systemd#1"]}
  groups={[]}
  name={"address"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### address

The TCP address to listen for connections on, or `systemd#N to use the Nth
socket passed by systemd socket activation. If an address is used it _must_
include a port.



</Field>
<Field
  common={false}
  defaultValue={30}
  enumValues={null}
  examples={[30]}
  groups={[]}
  name={"shutdown_timeout_secs"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={"seconds"}
  warnings={[]}
  >

### shutdown_timeout_secs

The timeout before a connection is forcefully closed during shutdown.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tls"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### tls

Configures the TLS options for connections from this source.


<Fields filters={false}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/certificate_authority.crt"]}
  groups={[]}
  name={"ca_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### ca_file

Absolute path to an additional CA certificate file, in DER or PEM format
(X.509), or an inline CA certificate in PEM format.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.crt"]}
  groups={[]}
  name={"crt_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### crt_file

Absolute path to a certificate file used to identify this server, in DER or PEM
format (X.509) or PKCS#12, or an inline certificate in PEM format. If this is
set and is not a PKCS#12 archive, [`key_file`](#key_file) must also be set. This is required
if [`enabled`](#enabled) is set to `true`.



</Field>
<Field
  common={true}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={[]}
  name={"enabled"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

#### enabled

Require TLS for incoming connections. If this is set, an identity certificate
is also required.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.key"]}
  groups={[]}
  name={"key_file"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_file

Absolute path to a private key file used to identify this server, in DER or PEM
format (PKCS#8), or an inline private key in PEM format.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["${KEY_PASS_ENV_VAR}","PassWord1"]}
  groups={[]}
  name={"key_pass"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### key_pass

Pass phrase used to unlock the encrypted key file. This has no effect unless
`key_file` is set.



</Field>
<Field
  common={false}
  defaultValue={false}
  enumValues={null}
  examples={[false,true]}
  groups={[]}
  name={"verify_certificate"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[{"visibility_level":"option","text":"Setting this to `false` will cause OpenSSL to not request a certificate from the client","option_name":"verify_certificate"}]}
  >

#### verify_certificate

If `true`, Vector will require a TLS certificate from the connecting host and
terminate the connection if it is not valid. If `false` (the default), Vector
will not request a certificate from the client.



</Field>
</Fields>

</Field>
</Fields>

## How It Works

### Encoding

Data is encoded via Vector's [event protobuf][urls.event_proto] before it is sent over the wire.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Message Acking

Currently, Vector does not perform any application level message acknowledgement. While rare, this means the individual message could be lost.

### TCP Protocol

Upstream Vector instances forward data to downstream Vector instances via the TCP protocol.



### TLS

Vector uses [Openssl][urls.openssl] for TLS protocols for it's battle-tested
and reliable security. You can enable and adjust TLS behavior via the [`tls.*`](#tls)
options.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model.metric]: /docs/about/data-model/metric/
[docs.sinks.vector]: /docs/reference/sinks/vector/
[urls.event_proto]: https://github.com/timberio/vector/blob/master/proto/event.proto
[urls.openssl]: https://www.openssl.org/
