---
last_modified_on: "2020-07-13"
component_title: "AWS EC2 Metadata"
description: "The Vector `aws_ec2_metadata` transform accepts and outputs `log` events, allowing you to enrich logs with AWS EC2 instance metadata."
event_types: ["log"]
function_category: "enrich"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+aws_ec2_metadata%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "aws_ec2_metadata|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/aws_ec2_metadata.rs
status: "beta"
title: "AWS EC2 Metadata Transform"
unsupported_operating_systems: []
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `aws_ec2_metadata` transform
accepts and outputs [`log`][docs.data-model.log] events, allowing you to enrich
logs with AWS EC2 instance metadata.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/aws_ec2_metadata.md.erb
-->

## Requirements

<Alert icon={false} type="danger" className="list--icons list--icons--warnings">


* [AWS IMDS v2][urls.aws_ec2_instance_metadata] is required. This is available by default on EC2.
* Running this transform within Docker on EC2 requires 2 network hops. Users must raise this limit. See the ["AWS imDS v2" section][docs.transforms.aws_ec2_metadata#aws-imds-v2] for more info.

</Alert>

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "aws_ec2_metadata" # required
  inputs = ["my-source-or-transform-id"] # required
  fields = ["instance-id", "local-hostname", "local-ipv4", "public-hostname", "public-ipv4", "ami-id", "availability-zone", "vpc-id", "subnet-id", "region"] # optional, default
  host = "http://169.254.169.254" # optional, default
  namespace = "" # optional, default
  refresh_interval_secs = 10 # optional, default
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "aws_ec2_metadata" # required
  inputs = ["my-source-or-transform-id"] # required
  fields = ["instance-id", "local-hostname", "local-ipv4", "public-hostname", "public-ipv4", "ami-id", "availability-zone", "vpc-id", "subnet-id", "region"] # optional, default
  host = "http://169.254.169.254" # optional, default
  namespace = "" # optional, default
  refresh_interval_secs = 10 # optional, default
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={["instance-id","local-hostname","local-ipv4","public-hostname","public-ipv4","ami-id","availability-zone","vpc-id","subnet-id","region"]}
  enumValues={null}
  examples={[["instance-id","local-hostname","local-ipv4","public-hostname","public-ipv4","ami-id","availability-zone","vpc-id","subnet-id","region"]]}
  groups={[]}
  name={"fields"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### fields

A list of fields to include in each event.



</Field>
<Field
  common={true}
  defaultValue={"http://169.254.169.254"}
  enumValues={null}
  examples={["http://169.254.169.254"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### host

Override the default EC2 Metadata host.



</Field>
<Field
  common={true}
  defaultValue={""}
  enumValues={null}
  examples={["","ec2","aws.ec2"]}
  groups={[]}
  name={"namespace"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### namespace

Prepend a namespace to each field's key.



</Field>
<Field
  common={true}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"refresh_interval_secs"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"uint"}
  unit={null}
  warnings={[]}
  >

### refresh_interval_secs

The interval in seconds at which the EC2 Metadata api will be called.



</Field>
</Fields>

## Fields

```javascript title="example log event"
{
  // ...
  "ami-id": "ami-00068cd7555f543d5",
  "availability-zone": "54.234.246.107",
  "instance-id": "i-096fba6d03d36d262",
  "local-hostname": "ip-172-31-93-227.ec2.internal",
  "local-ipv4": "172.31.93.227",
  "public-hostname": "ec2-54-234-246-107.compute-1.amazonaws.com",
  "public-ipv4": "54.234.246.107",
  "region": "us-east-1",
  "role-name": "some_iam_role",
  "subnet-id": "subnet-9d6713b9",
  "vpc-id": "vpc-a51da4dc"
  // ...
}
```

<Fields filters={true}>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["ami-00068cd7555f543d5"]}
  groups={[]}
  name={"ami-id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### ami-id

The `ami-id` that the current EC2 instance is using.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["54.234.246.107"]}
  groups={[]}
  name={"availability-zone"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### availability-zone

The `availability-zone` that the current EC2 instance is running in.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["i-096fba6d03d36d262"]}
  groups={[]}
  name={"instance-id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### instance-id

The `instance-id` of the current EC2 instance.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["ip-172-31-93-227.ec2.internal"]}
  groups={[]}
  name={"local-hostname"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### local-hostname

The `local-hostname` of the current EC2 instance.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["172.31.93.227"]}
  groups={[]}
  name={"local-ipv4"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### local-ipv4

The `local-ipv4` of the current EC2 instance.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["ec2-54-234-246-107.compute-1.amazonaws.com"]}
  groups={[]}
  name={"public-hostname"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### public-hostname

The `public-hostname` of the current EC2 instance.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["54.234.246.107"]}
  groups={[]}
  name={"public-ipv4"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### public-ipv4

The `public-ipv4` of the current EC2 instance.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["us-east-1"]}
  groups={[]}
  name={"region"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### region

The [`region`](#region) that the current EC2 instance is running in.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["some_iam_role"]}
  groups={[]}
  name={"role-name"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### role-name

The `role-name` that the current EC2 instance is using.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["subnet-9d6713b9"]}
  groups={[]}
  name={"subnet-id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### subnet-id

The `subnet-id` of the current EC2 instance's default network interface.



</Field>
<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["vpc-a51da4dc"]}
  groups={[]}
  name={"vpc-id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### vpc-id

The `vpc-id` of the current EC2 instance's default network interface.



</Field>
</Fields>

## How It Works

### AWS IMDS v2

v2 of the [AWS IMDS service][urls.aws_ec2_instance_metadata] addresses [a number
of very serious security issues][urls.aws_imds_v1_security_problems] with v1.
As part of tighening security, Amazon limited the number of network hops allowed
to communicate with this service to 1. Unfortunately, when running Vector within
Docker this introduces an additional hop. Therefore, you _must_ configure your
AWS instances to allow for 2 hops:

```bash
aws ec2 modify-instance-metadata-options --instance-id <ID> --http-endpoint enabled --http-put-response-hop-limit 2
```

If you do not raise this limit the `aws_ec2_metadata` transform will not work.

### Complex Processing

If you encounter limitations with the `aws_ec2_metadata`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.transforms.aws_ec2_metadata#aws-imds-v2]: /docs/reference/transforms/aws_ec2_metadata/#aws-imds-v2
[urls.aws_ec2_instance_metadata]: https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-metadata.html
[urls.aws_imds_v1_security_problems]: https://aws.amazon.com/blogs/security/defense-in-depth-open-firewalls-reverse-proxies-ssrf-vulnerabilities-ec2-instance-metadata-service/
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
