---
last_modified_on: "2020-07-13"
component_title: "Concat"
description: "The Vector `concat` transform accepts and outputs `log` events, allowing you to concat (substrings) of other fields to a new one."
event_types: ["log"]
function_category: "schema"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+concat%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "concat|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/concat.rs
status: "beta"
title: "Concat Transform"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `concat` transform
accepts and outputs [`log`][docs.data-model.log] events, allowing you to concat
(substrings) of other fields to a new one.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/concat.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "concat" # required
  inputs = ["my-source-or-transform-id"] # required
  items = ["first[..3]", "second[-5..]", "third[3..6]"] # required
  target = "root_field_name" # required
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "concat" # required
  inputs = ["my-source-or-transform-id"] # required
  items = ["first[..3]", "second[-5..]", "third[3..6]"] # required
  joiner = " " # optional, default
  target = "root_field_name" # required
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["first[..3]","second[-5..]","third[3..6]"]]}
  groups={[]}
  name={"items"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### items

A list of substring definitons in the format of source_field[start..end]. For
both start and end negative values are counted from the end of the string.



</Field>
<Field
  common={false}
  defaultValue={" "}
  enumValues={null}
  examples={[" ",",","_","+"]}
  groups={[]}
  name={"joiner"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### joiner

The string that is used to join all items.



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["root_field_name","parent.child","array[0]"]}
  groups={[]}
  name={"target"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### target

The name for the new label.
 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
</Fields>

## Examples

Given the following input log event:

```json
{
  "message": "Hello world",
  "month": "12",
  "day": "25",
  "year": "2020"
}
```

And the following example configuration:

```toml
[transforms.concat_date]
  type = "concat"
  items = ["month", "day", "year"]
  target = "date"
  joiner = "/"
```

A log event will be output with the following structure:

```json
{
  "message": "Hello world",
  "date": "12/25/2020", // <-- new field
  "month": "12",
  "day": "25",
  "year": "2020"
}
```

## How It Works

### Complex Processing

If you encounter limitations with the `concat`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Field Notation Syntax

The [`target`](#target) options
support [Vector's field notation syntax][docs.reference.field-path-notation],
enabling access to root-level, nested, and array field values. For example:

```toml title="vector.toml"
[transforms.my_concat_transform_id]
  # ...
  target = "root_field_name"
  target = "parent.child"
  target = "array[0]"
  # ...
```

You can learn more about Vector's field notation in the
[field notation reference][docs.reference.field-path-notation].

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.field-path-notation]: /docs/reference/field-path-notation/
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
