---
last_modified_on: "2020-07-13"
component_title: "Grok Parser"
description: "The Vector `grok_parser` transform accepts and outputs `log` events, allowing you to parse a log field value with Grok."
event_types: ["log"]
function_category: "parse"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+grok_parser%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "grok_parser|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/grok_parser.rs
status: "prod-ready"
title: "Grok Parser Transform"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `grok_parser` transform
accepts and outputs [`log`][docs.data-model.log] events, allowing you to parse
a log field value with [Grok][urls.grok].

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/grok_parser.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "grok_parser" # required
  inputs = ["my-source-or-transform-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default
  pattern = "%{TIMESTAMP_ISO8601:timestamp} %{LOGLEVEL:level} %{GREEDYDATA:message}" # required

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "grok_parser" # required
  inputs = ["my-source-or-transform-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default
  pattern = "%{TIMESTAMP_ISO8601:timestamp} %{LOGLEVEL:level} %{GREEDYDATA:message}" # required

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"drop_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### drop_field

If `true` will drop the specified [`field`](#field) after parsing.



</Field>
<Field
  common={true}
  defaultValue={"message"}
  enumValues={null}
  examples={["message","parent.child","array[0]"]}
  groups={[]}
  name={"field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### field

The log field to execute the [`pattern`](#pattern) against. Must be a `string` value.
 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["%{TIMESTAMP_ISO8601:timestamp} %{LOGLEVEL:level} %{GREEDYDATA:message}"]}
  groups={[]}
  name={"pattern"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### pattern

The [Grok pattern][urls.grok_patterns]



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"types"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### types

Key/value pairs representing mapped log field names and types. This is used to
coerce log fields into their proper types.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"bool":"Coerces `\"true\"`/`/\"false\"`, `\"1\"`/`\"0\"`, and `\"t\"`/`\"f\"` values into boolean.","float":"Coerce to a 64 bit float.","int":"Coerce to a 64 bit integer.","string":"Coerce to a string.","timestamp":"Coerces to a Vector timestamp. [`strptime` specificiers][urls.strptime_specifiers] must be used to parse the string."}}
  examples={[{"status":"int"},{"duration":"float"},{"success":"bool"},{"timestamp":"timestamp|%F"},{"timestamp":"timestamp|%a %b %e %T %Y"},{"parent":{"child":"int"}}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"types"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[field-name]`

A definition of log field type conversions. They key is the log field name and
the value is the type. [`strptime` specifiers][urls.strptime_specifiers] are
supported for the `timestamp` type.



</Field>
</Fields>

</Field>
</Fields>

## How It Works

### Available Patterns

Vector uses the Rust [`grok` library][urls.rust_grok_library]. All patterns
[listed here][urls.grok_patterns] are supported. It is recommended to use
maintained patterns when possible since they can be improved over time by
the community.

### Complex Processing

If you encounter limitations with the `grok_parser`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Debugging

We recommend the [Grok debugger][urls.grok_debugger] for Grok testing.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Field Notation Syntax

The [`field`](#field) options
support [Vector's field notation syntax][docs.reference.field-path-notation],
enabling access to root-level, nested, and array field values. For example:

```toml title="vector.toml"
[transforms.my_grok_parser_transform_id]
  # ...
  field = "message"
  field = "parent.child"
  field = "array[0]"
  # ...
```

You can learn more about Vector's field notation in the
[field notation reference][docs.reference.field-path-notation].

### Performance

Grok is approximately 50% slower than the [`regex_parser` transform][docs.transforms.regex_parser].
We plan to add a [performance test][pages.index#performance] for this in the future.
While this is still plenty fast for most use cases we recommend using the
[`regex_parser` transform][docs.transforms.regex_parser] if you are experiencing
performance issues.



### Value Coercion

Values can be coerced upon extraction via the [`types.*`](#types) options. This functions
exactly like the [`coercer` transform][docs.transforms.coercer] except that its
coupled within this transform for convenience.

#### Timestamps

You can coerce values into timestamps via the `timestamp` type:

```toml title="vector.toml"
# ...
types.first_timestamp = "timestamp" # best effort parsing
types.second_timestamp = "timestamp|%Y-%m-%dT%H:%M:%S%z" # ISO8601
# ...
```

As noted above, if you do not specify a specific `strftime` format, Vector
will make a best effort attempt to parse the timestamp against the following
common formats:

| Format               | Description                                  |
|:---------------------|:---------------------------------------------|
| **Without Timezone** |                                              |
| `%F %T`              | YYYY-MM-DD HH:MM:SS                          |
| `%v %T`              | DD-Mmm-YYYY HH:MM:SS                         |
| `FT%T`               | ISO 8601 / RFC 3339 without TZ               |
| `m/%d/%Y:%T`         | US common date format                        |
| `a, %d %b %Y %T`     | RFC 822/2822 without TZ                      |
| `a %d %b %T %Y`      | `date` command output without TZ             |
| `A %d %B %T %Y`      | `date` command output without TZ, long names |
| `a %b %e %T %Y`      | ctime format                                 |
| **With Timezone**    |                                              |
| `%+`                 | ISO 8601 / RFC 3339                          |
| `%a %d %b %T %Z %Y`  | `date` command output                        |
| `%a %d %b %T %z %Y`  | `date` command output, numeric TZ            |
| `%a %d %b %T %#z %Y` | `date` command output, numeric TZ            |
| **UTC Formats**      |                                              |
| `%s`                 | UNIX timestamp                               |
| `%FT%TZ`             | ISO 8601 / RFC 3339 UTC                      |

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.field-path-notation]: /docs/reference/field-path-notation/
[docs.transforms.coercer]: /docs/reference/transforms/coercer/
[docs.transforms.regex_parser]: /docs/reference/transforms/regex_parser/
[pages.index#performance]: /#performance
[urls.grok]: https://grokdebug.herokuapp.com/
[urls.grok_debugger]: https://grokdebug.herokuapp.com/
[urls.grok_patterns]: https://github.com/daschl/grok/tree/master/patterns
[urls.rust_grok_library]: https://github.com/daschl/grok
[urls.strptime_specifiers]: https://docs.rs/chrono/0.4.11/chrono/format/strftime/index.html#specifiers
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
