---
last_modified_on: "2020-07-13"
component_title: "Split"
description: "The Vector `split` transform accepts and outputs `log` events, allowing you to split a field's value on a _literal_ separator and zip the tokens into ordered field names."
event_types: ["log"]
function_category: "parse"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+split%22
operating_systems: ["Linux","MacOS","Windows"]
sidebar_label: "split|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/split.rs
status: "prod-ready"
title: "Split Transform"
unsupported_operating_systems: []
---

import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `split` transform
accepts and outputs [`log`][docs.data-model.log] events, allowing you to split
a field's value on a _literal_ separator and zip the tokens into ordered field
names.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/split.md.erb
-->

## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "split" # required
  inputs = ["my-source-or-transform-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default
  field_names = ["timestamp", "level", "message", "parent.child"] # required
  separator = "[whitespace]" # optional, default

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  # General
  type = "split" # required
  inputs = ["my-source-or-transform-id"] # required
  drop_field = true # optional, default
  field = "message" # optional, default
  field_names = ["timestamp", "level", "message", "parent.child"] # required
  separator = "[whitespace]" # optional, default

  # Types
  types.status = "int" # example
  types.duration = "float" # example
  types.success = "bool" # example
  types.timestamp = "timestamp|%F" # example
  types.timestamp = "timestamp|%a %b %e %T %Y" # example
  types.parent.child = "int" # example
```

</TabItem>
</Tabs>

<Fields filters={true}>
<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"drop_field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  warnings={[]}
  >

### drop_field

If `true` the [`field`](#field) will be dropped after parsing.



</Field>
<Field
  common={true}
  defaultValue={"message"}
  enumValues={null}
  examples={["message","parent.child"]}
  groups={[]}
  name={"field"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### field

The field to apply the split on.
 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["timestamp","level","message","parent.child"]]}
  groups={[]}
  name={"field_names"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### field_names

The field names assigned to the resulting tokens, in order.
 See [Field Notation Syntax](#field-notation-syntax) for more info.


</Field>
<Field
  common={true}
  defaultValue={"[whitespace]"}
  enumValues={null}
  examples={[","]}
  groups={[]}
  name={"separator"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"[string]"}
  unit={null}
  warnings={[]}
  >

### separator

The separator to split the field on. If no separator is given, it will split on
all whitespace. 'Whitespace' is defined according to the terms of the [Unicode
Derived Core Property `White_Space`][urls.unicode_whitespace].



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"types"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  warnings={[]}
  >

### types

Key/value pairs representing mapped log field names and types. This is used to
coerce log fields into their proper types.


<Fields filters={false}>
<Field
  common={true}
  defaultValue={null}
  enumValues={{"bool":"Coerces `\"true\"`/`/\"false\"`, `\"1\"`/`\"0\"`, and `\"t\"`/`\"f\"` values into boolean.","float":"Coerce to a 64 bit float.","int":"Coerce to a 64 bit integer.","string":"Coerce to a string.","timestamp":"Coerces to a Vector timestamp. [`strptime` specificiers][urls.strptime_specifiers] must be used to parse the string."}}
  examples={[{"status":"int"},{"duration":"float"},{"success":"bool"},{"timestamp":"timestamp|%F"},{"timestamp":"timestamp|%a %b %e %T %Y"},{"parent":{"child":"int"}}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"types"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

#### `[field-name]`

A definition of log field type conversions. They key is the log field name and
the value is the type. [`strptime` specifiers][urls.strptime_specifiers] are
supported for the `timestamp` type.



</Field>
</Fields>

</Field>
</Fields>

## Examples

Given the following log line:

```json
{
  "message": "5.86.210.12,zieme4647,19/06/2019:17:20:49 -0400,GET /embrace/supply-chains/dynamic/vertical,201,20574"
}
```

And the following configuration:

```toml
[transforms.<transform-id>]
  type = "split"
  field = "message"
  separator = ","
  fields = ["remote_addr", "user_id", "timestamp", "message", "status", "bytes"]

  types.status = "int"
  types.bytes = "int"
```

A [`log` event][docs.data-model.log] will be output with the following structure:

```javascript
{
  // ... existing fields
  "remote_addr": "5.86.210.12",
  "user_id": "zieme4647",
  "timestamp": "19/06/2019:17:20:49 -0400",
  "message": "GET /embrace/supply-chains/dynamic/vertical",
  "status": 201,
  "bytes": 20574
}
```

A couple of things to notice:

1. The `message` field was overwritten since it was provided in the `fields` option.
2. The `status` and `bytes` fields are integers because of type coercion, otherwise they would be strings.

## How It Works

### Complex Processing

If you encounter limitations with the `split`
transform then we recommend using a [runtime transform][urls.vector_programmable_transforms].
These transforms are designed for complex processing and give you the power of
full programming runtime.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

### Field Notation Syntax

The [`field`](#field) and [`field_names`](#field_names) options
support [Vector's field notation syntax][docs.reference.field-path-notation],
enabling access to root-level, nested, and array field values. For example:

```toml title="vector.toml"
[transforms.my_split_transform_id]
  # ...
  field = "message"
  field = "parent.child"
  # ...
```

You can learn more about Vector's field notation in the
[field notation reference][docs.reference.field-path-notation].

### Value Coercion

Values can be coerced upon extraction via the [`types.*`](#types) options. This functions
exactly like the [`coercer` transform][docs.transforms.coercer] except that its
coupled within this transform for convenience.

#### Timestamps

You can coerce values into timestamps via the `timestamp` type:

```toml title="vector.toml"
# ...
types.first_timestamp = "timestamp" # best effort parsing
types.second_timestamp = "timestamp|%Y-%m-%dT%H:%M:%S%z" # ISO8601
# ...
```

As noted above, if you do not specify a specific `strftime` format, Vector
will make a best effort attempt to parse the timestamp against the following
common formats:

| Format               | Description                                  |
|:---------------------|:---------------------------------------------|
| **Without Timezone** |                                              |
| `%F %T`              | YYYY-MM-DD HH:MM:SS                          |
| `%v %T`              | DD-Mmm-YYYY HH:MM:SS                         |
| `FT%T`               | ISO 8601 / RFC 3339 without TZ               |
| `m/%d/%Y:%T`         | US common date format                        |
| `a, %d %b %Y %T`     | RFC 822/2822 without TZ                      |
| `a %d %b %T %Y`      | `date` command output without TZ             |
| `A %d %B %T %Y`      | `date` command output without TZ, long names |
| `a %b %e %T %Y`      | ctime format                                 |
| **With Timezone**    |                                              |
| `%+`                 | ISO 8601 / RFC 3339                          |
| `%a %d %b %T %Z %Y`  | `date` command output                        |
| `%a %d %b %T %z %Y`  | `date` command output, numeric TZ            |
| `%a %d %b %T %#z %Y` | `date` command output, numeric TZ            |
| **UTC Formats**      |                                              |
| `%s`                 | UNIX timestamp                               |
| `%FT%TZ`             | ISO 8601 / RFC 3339 UTC                      |

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.reference.field-path-notation]: /docs/reference/field-path-notation/
[docs.transforms.coercer]: /docs/reference/transforms/coercer/
[urls.strptime_specifiers]: https://docs.rs/chrono/0.4.11/chrono/format/strftime/index.html#specifiers
[urls.unicode_whitespace]: https://en.wikipedia.org/wiki/Unicode_character_property#Whitespace
[urls.vector_programmable_transforms]: https://vector.dev/components/?functions%5B%5D=program
