---
last_modified_on: "2020-07-13"
component_title: "WASM"
description: "The Vector `wasm` transform accepts and outputs `log` events, allowing you to execute **experimental** WASM plugins."
event_types: ["log"]
function_category: "program"
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+wasm%22
operating_systems: ["Linux"]
sidebar_label: "wasm|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/wasm.rs
status: "beta"
title: "WASM Transform"
unsupported_operating_systems: ["MacOS","Windows"]
---

import Alert from '@site/src/components/Alert';
import Fields from '@site/src/components/Fields';
import Field from '@site/src/components/Field';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

The Vector `wasm` transform
accepts and outputs [`log`][docs.data-model.log] events, allowing you to
execute **experimental** WASM plugins.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/wasm.md.erb
-->

## Requirements

<Alert icon={false} type="danger" className="list--icons list--icons--warnings">

* Vector must be build with the `wasm` feature. *This is not enabled by default. Review [Building Vector][urls.contributing]*.

</Alert>


## Configuration

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>
<TabItem value="common">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "wasm" # required
  inputs = ["my-source-or-transform-id"] # required
  artifact_cache = "/etc/vector/artifacts" # required
  heap_max_size = 10485760 # optional, default
  module = "./modules/example.wasm" # required
```

</TabItem>
<TabItem value="advanced">

```toml title="vector.toml"
[transforms.my_transform_id]
  type = "wasm" # required
  inputs = ["my-source-or-transform-id"] # required
  artifact_cache = "/etc/vector/artifacts" # required
  heap_max_size = 10485760 # optional, default
  module = "./modules/example.wasm" # required
```

</TabItem>
</Tabs>

## Options

<Fields filters={true}>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/etc/vector/artifacts","/var/lib/vector/artifacts","C:\\vector\\artifacts"]}
  groups={[]}
  name={"artifact_cache"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### artifact_cache

The directory where Vector should store the artifact it builds of this WASM
module. Typically, all WASM modules share this.



</Field>
<Field
  common={true}
  defaultValue={10485760}
  enumValues={null}
  examples={[10485760]}
  groups={[]}
  name={"heap_max_size"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  warnings={[]}
  >

### heap_max_size

The maximum size of the heap of this module, in bytes. (This includes the
module itself, default is 10 MB.)



</Field>
<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["./modules/example.wasm","/example.wat","example.wasm"]}
  groups={[]}
  name={"module"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  warnings={[]}
  >

### module

The file path of the `.wasm` or `.wat` module.



</Field>
</Fields>

## Examples

Given the following configuration:

<CodeHeader fileName="vector.toml" />

```toml title="vector.toml"
[transforms.test]
  inputs = [...]
  type = "wasm"
  module = "module.wasm"
  artifact_cache = "artifacts/"
```

Accompanied by a `module.wasm` file built via `cargo +nightly --target wasm32-wasi ...`, Vector will use the module as a
custom transform.

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the
[Environment Variables][docs.configuration#environment-variables] section.

[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[urls.contributing]: https://github.com/timberio/vector/blob/master/CONTRIBUTING.md#setup
