---
last_modified_on: "2020-07-13"
title: Install Vector via Homebrew
sidebar_label: Homebrew
description: Install Vector through the Homebrew package manager
---

import ConfigExample from '@site/src/components/ConfigExample';
import DaemonDiagram from '@site/src/components/DaemonDiagram';
import Jump from '@site/src/components/Jump';
import Steps from '@site/src/components/Steps';
import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

Vector can be installed through [Homebrew][urls.homebrew] which is generally
used on MacOS systems.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/package-managers/homebrew.md.erb
-->

## Install

<Tabs
  block={true}
  defaultValue="daemon"
  values={[{"label":"As a Daemon","value":"daemon"}]}>
<TabItem value="daemon">

The [daemon deployment strategy][docs.strategies#daemon] is designed for data
collection on a single host. Vector runs in the background, in its own process,
collecting _all_ data for that host.
Typically data is collected from a process manager, such as Journald via
Vector's [`journald` source][docs.sources.journald], but can be collected
through any of Vector's [sources][docs.sources].
The following diagram demonstrates how it works.

<DaemonDiagram
  platformName={null}
  sourceName={null}
  sinkName={null} />

---

<Tabs
  centered={true}
  className={"rounded"}
  defaultValue={"homebrew"}
  placeholder="Please choose an installation method..."
  select={false}
  size={null}
  values={[{"group":"Package managers","label":"Homebrew","value":"homebrew"}]}>
<TabItem value="homebrew">

<Steps headingDepth={3}>
<ol>
<li>

### Add the Timber tap and install `vector`

```bash
brew tap timberio/brew && brew install vector
```

[Looking for a specific version?][docs.package_managers.homebrew]

</li>
<li>

### Configure Vector

<ConfigExample
  format="toml"
  path={"/etc/vector/vector.toml"}
  sourceName={"file"}
  sinkName={null} />

</li>
<li>

### Start Vector

```bash
brew services start vector
```

</li>
</ol>
</Steps>

</TabItem>
</Tabs>
</TabItem>
</Tabs>

## Configuring

The Vector configuration file is placed in:

```text
/usr/local/etc/vector/vector.toml
```

A full spec is located at `/usr/local/etc/vector/vector.spec.toml` and examples
are located in `/usr/local/etc/vector/examples/*`. You can learn more about
configuring Vector in the [Configuration][docs.configuration] section.

## Deploying

How you deploy Vector is largely dependent on your use case and environment.
Please see the [deployment section][docs.deployment] for more info on how to
deploy Vector.

## Administering

Vector can be managed through the [Homebrew services][urls.homebrew_services]
manager:

<Jump to="/docs/administration">Administration</Jump>

## Uninstalling

```bash
brew remove vector
```

## Updating

```bash
brew update && brew upgrade vector
```

## Package

### Architectures

Vector's Homebrew packages only support the X86_64 arhcitecture.

### Versions

Historical Vector versions can be found in the [releases][urls.vector_releases].
Once you've found the version you'd like to install you can specify it with:

```bash
brew install vector@X.X.X
```

Due to limitations of Homebrew, Vector cannot pin specific major or minor
versions. If this is a requirement, then we recommend installing Vector
directly [from an archive][docs.manual.from-archives].

### Source Files

Vector's Homebrew source files are located in
[Vector's brew repo][urls.vector_homebrew_source_files].

[docs.configuration]: /docs/setup/configuration/
[docs.deployment]: /docs/setup/deployment/
[docs.manual.from-archives]: /docs/setup/installation/manual/from-archives/
[docs.package_managers.homebrew]: /docs/setup/installation/package-managers/homebrew/
[docs.sources.journald]: /docs/reference/sources/journald/
[docs.sources]: /docs/reference/sources/
[docs.strategies#daemon]: /docs/setup/deployment/strategies/#daemon
[urls.homebrew]: https://brew.sh/
[urls.homebrew_services]: https://github.com/Homebrew/homebrew-services
[urls.vector_homebrew_source_files]: https://github.com/timberio/homebrew-brew/blob/master/Formula/vector.rb
[urls.vector_releases]: https://vector.dev/releases/latest/
